
/*  ___   ___  ___  _   _  ___   ___   ____ ___  ____  
 * / _ \ /___)/ _ \| | | |/ _ \ / _ \ / ___) _ \|    \ 
 *| |_| |___ | |_| | |_| | |_| | |_| ( (__| |_| | | | |
 * \___/(___/ \___/ \__  |\___/ \___(_)____)___/|_|_|_|
 *                  (____/ 
 * OSOYOO IoT Tutorial: Use OSOYOO IoT APP to display the values of light sensor 
 * remotely connected to the OSOYOO NodeMCU 
 * For more details see: https://osoyoo.com/?p=52693
 */

#include <ESP8266WiFi.h>
#include <WiFiUdp.h>

#ifndef STASSID
#define STASSID "***" // replace *** with your wifi SSID
#define STAPSK  "***" // replace *** with your wifi password
#endif

unsigned int localPort = 8888;      // local port to listen on

// buffers for receiving and sending data
char packetBuffer[UDP_TX_PACKET_MAX_SIZE + 1]; //buffer to hold incoming packet,

WiFiUDP Udp;

#define lightsensor A0

//IPAddress phoneIP=IPAddress(192,168,1,255);//if your Arduino IP is sth like 192.168.0.xx set this value to 192.168.0.255

void setup() {

  Serial.begin(115200);
  WiFi.mode(WIFI_STA);
  WiFi.begin(STASSID, STAPSK);
  while (WiFi.status() != WL_CONNECTED) {
    Serial.println('.');
    delay(500);
  }
  Serial.println("Connected! IP address: ");
  Serial.println(WiFi.localIP());
  Serial.printf("UDP server on port %d\n", localPort);
  Udp.begin(localPort);

}

unsigned long oldTime = 0;
unsigned long currentTime = 0;

void loop() {

  currentTime = millis();

    int val = analogRead(lightsensor);
    String msg = "Light value: ";
    Serial.println("Real time light strength: ");
    msg = msg + val;
    msg += "\n";
    Serial.println(msg);
    delay(5000);

  // if there's data available, read a packet

  int packetSize = Udp.parsePacket();
  if (packetSize) {
    Serial.printf("Received packet of size %d from %s:%d\n    (to %s:%d, free heap = %d B)\n",
                  packetSize,
                  Udp.remoteIP().toString().c_str(), Udp.remotePort(),
                  Udp.destinationIP().toString().c_str(), Udp.localPort(),
                  ESP.getFreeHeap());

    // read the packet into packetBufffer
    int n = Udp.read(packetBuffer, UDP_TX_PACKET_MAX_SIZE);
    packetBuffer[n] = 0;
    Serial.println("Contents:");
    Serial.println(packetBuffer);
    if (packetBuffer[0] == 'F') // when F1 button is pressed in OSOYOO IoT APP
    {
      IPAddress phoneIP = Udp.remoteIP();

      if (currentTime > oldTime + 2000) {
        oldTime = currentTime;
        Udp.beginPacket(phoneIP, 8888);
        // Send light sensor value back to the UDP client app
        Udp.write(msg.c_str());
        Udp.endPacket();
      }
    }
  }
}

 
